/// <reference types="node" />
import { IncomingRecommendationEmailRenderer } from './IncomingRecommendationEmailRenderer';
import { RecommendationService } from './RecommendationService';
export type IncomingRecommendation = {
    id: string;
    title: string;
    url: URL;
    excerpt: string | null;
    favicon: URL | null;
    featuredImage: URL | null;
    recommendingBack: boolean;
};
export type Report = {
    startDate: Date;
    endDate: Date;
    recommendations: IncomingRecommendation[];
};
type Mention = {
    id: string;
    source: URL;
    sourceTitle: string;
    sourceSiteTitle: string | null;
    sourceAuthor: string | null;
    sourceExcerpt: string | null;
    sourceFavicon: URL | null;
    sourceFeaturedImage: URL | null;
};
type MentionMeta = {
    pagination: {
        page: number;
        limit: number;
        pages: number;
        total: number;
        next: null | number;
        prev: null | number;
    };
};
type MentionsAPI = {
    refreshMentions(options: {
        filter: string;
        limit: number | 'all';
    }): Promise<void>;
    listMentions(options: {
        filter: string;
        page: number;
        limit: number | 'all';
    }): Promise<{
        data: Mention[];
        meta?: MentionMeta;
    }>;
};
export type EmailRecipient = {
    email: string;
};
type EmailService = {
    send(to: string, subject: string, html: string, text: string): Promise<void>;
};
export declare class IncomingRecommendationService {
    #private;
    constructor(deps: {
        recommendationService: RecommendationService;
        mentionsApi: MentionsAPI;
        emailService: EmailService;
        emailRenderer: IncomingRecommendationEmailRenderer;
        getEmailRecipients: () => Promise<EmailRecipient[]>;
    });
    init(): Promise<void>;
    sendRecommendationEmail(mention: Mention): Promise<void>;
    listIncomingRecommendations(options: {
        page?: number;
        limit?: number | 'all';
    }): Promise<{
        incomingRecommendations: IncomingRecommendation[];
        meta?: MentionMeta;
    }>;
}
export {};
